@@ -14,5 +14,5 @@ if (REIFY_PARSER === "acorn" ||
 } else try {
   exports.parse = dynRequire(REIFY_PARSER);
 } catch (e) {
-  exports.parse = require("./acorn.js").parse;
+  exports.parse = dynRequire("./acorn.js").parse;
 }
